#ifndef _PHOTSOLVE_H_
#define _PHOTSOLVE_H_

#define MAX_COLORS 16


/* status of pfit values */
#define PFIT_IMAG_VALID 1
#define PFIT_IMAGERR_VALID 2
#define PFIT_SMAG_VALID 4
#define PFIT_SMAGERR_VALID 8
#define PFIT_COLOR_VALID 0x10
#define PFIT_COLORERR_VALID 0x20

/* describe a star for photometry fitting purposes */
struct pfit_star {
	int flags;
	double imag;  /* the instrumental magnitude in iband */
	double imag_err; /* estimated error of imag */
	double smag; /* standard magnitude in sband */ 
	double smag_err; /* estimated error of smag */
	double color; /* color index for this star */
	double color_err; /* error of color index */
	double residual; /* current fit residual */
	double weight; /* current weight for this star */
};

#define BAND_NAME_SIZE 256
/* bands we're using for the fit */
struct band_names {
	char iband[BAND_NAME_SIZE+1]; /* names of the instrumental band we're fitting */
	char sband[BAND_NAME_SIZE+1]; /* name of the the standard band we're using
		       * should corespond to the iband */
	char color[BAND_NAME_SIZE+1]; /* name of the color we use */
};


#define TRANSFORM_ZEROP_VALID 1
#define TRANSFORM_COLTERM_VALID 2
/* describe a transformation */
struct star_transform {
	int flags;
	double zerop; /* zero-point of the transform */
	double colterm; /* color term coefficient */
	double cov_zz; /* covariance terms from the fit */
	double cov_zc;
	double cov_cc;
};

/* function declarations */

void fit_std_stars(struct pfit_star *stds, int nstd, struct star_transform *trans,
		   double *meu);
void transform_stars(struct pfit_star *pgms, int npgm, struct star_transform *trans);




/* declarations from gsl-1.3 (gsl_fit.h) */

/* fit/gsl_fit.h
 * 
 * Copyright (C) 2000 Brian Gough
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


int gsl_fit_linear (const double * x, const size_t xstride,
                    const double * y, const size_t ystride,
                    const size_t n,
                    double * c0, double * c1, 
                    double * cov00, double * cov01, double * cov11, 
                    double * sumsq);


int gsl_fit_wlinear (const double * x, const size_t xstride,
                     const double * w, const size_t wstride,
                     const double * y, const size_t ystride,
                     const size_t n,
                     double * c0, double * c1, 
                     double * cov00, double * cov01, double * cov11, 
                     double * chisq);

int
gsl_fit_linear_est (const double x, 
                    const double c0, const double c1, 
                    const double c00, const double c01, const double c11,
                    double *y, double *y_err);


int gsl_fit_mul (const double * x, const size_t xstride,
                 const double * y, const size_t ystride,
                 const size_t n,
                 double * c1, 
                 double * cov11, 
                 double * sumsq);

int gsl_fit_wmul (const double * x, const size_t xstride,
                  const double * w, const size_t wstride,
                  const double * y, const size_t ystride,
                  const size_t n,
                  double * c1, 
                  double * cov11, 
                  double * sumsq);


int
gsl_fit_mul_est (const double x, 
                 const double c1, 
                 const double c11,
                 double *y, double *y_err);


#endif
